@@ -8,8 +8,9 @@ import json
 from datetime import datetime
 from pathlib import Path
 from chardet.universaldetector import UniversalDetector
+from dataclasses import dataclass
+from typing import Dict, Set
 
-import regex as re
 import progressbar
 import numpy as np
 import xarray as xr
@@ -104,92 +105,6 @@ def get_return_elements(return_columns, namespace):
     return list(capture_elements), return_addresses
 
 
-def make_flat_df(df, return_addresses, flatten=False):
-    """
-    Takes a dataframe from the outputs of the integration processes,
-    renames the columns as the given return_adresses and splits xarrays
-    if needed.
-
-    Parameters
-    ----------
-    df: Pandas.DataFrame
-        Output from the integration.
-
-    return_addresses: dict
-        Keys will be column names of the resulting dataframe, and are what the
-        user passed in as 'return_columns'. Values are a tuple:
-        (py_name, {coords dictionary}) which tells us where to look for the
-        value to put in that specific column.
-
-    flatten: bool (optional)
-            If True, once the output dataframe has been formatted will
-            split the xarrays in new columns following vensim's naming
-            to make a totally flat output. Default is False.
-
-    Returns
-    -------
-    new_df: pandas.DataFrame
-        Formatted dataframe.
-
-    """
-    new_df = {}
-    for real_name, (pyname, address) in return_addresses.items():
-        if address:
-            # subset the specific address
-            values = [x.loc[address] for x in df[pyname].values]
-        else:
-            # get the full column
-            values = df[pyname].to_list()
-
-        is_dataarray = len(values) != 0 and isinstance(values[0], xr.DataArray)
-
-        if is_dataarray and values[0].size == 1:
-            # some elements are returned as 0-d arrays, convert
-            # them to float
-            values = [float(x) for x in values]
-            is_dataarray = False
-
-        if flatten and is_dataarray:
-            _add_flat(new_df, real_name, values)
-        else:
-            new_df[real_name] = values
-
-    return pd.DataFrame(index=df.index, data=new_df)
-
-
-def _add_flat(savedict, name, values):
-    """
-    Add float lists from a list of xarrays to a provided dictionary.
-
-    Parameters
-    ----------
-    savedict: dict
-        Dictionary to save the data on.
-
-    name: str
-        The base name of the variable to save the data.
-
-    values: list
-        List of xarrays to convert to split in floats.
-
-    Returns
-    -------
-    None
-
-    """
-    # remove subscripts from name if given
-    name = re.sub(r'\[.*\]', '', name)
-    dims = values[0].dims
-
-    # split values in xarray.DataArray
-    lval = [xrsplit(val) for val in values]
-    for i, ar in enumerate(lval[0]):
-        vals = [float(v[i]) for v in lval]
-        subs = '[' + ','.join([str(ar.coords[dim].values)
-                               for dim in dims]) + ']'
-        savedict[name+subs] = vals
-
-
 def compute_shape(coords, reshape_len=None, py_name=""):
     """
     Computes the 'shape' of a coords dictionary.
@@ -305,9 +220,10 @@ def rearrange(data, dims, coords):
             return xr.DataArray(data=data.values, coords=coords, dims=dims)
         elif np.prod(shape) < np.prod(data.shape):
             # Allows subscripting a subrange
-            return data.rename(
-                {dim: new_dim for dim, new_dim in zip(data.dims, dims)}
-            ).loc[coords]
+            return data.rename({
+                dim: new_dim for dim, new_dim in zip(data.dims, dims)
+                if dim != new_dim
+            }).loc[coords]
 
         # The coordinates are expanded or transposed
         return xr.DataArray(0, coords, dims) + data
@@ -498,6 +414,49 @@ def print_objects_format(object_set, text):
     return text
 
 
+@dataclass
+class Dependencies():
+    """
+    Representation of variables dependencies.
+
+    Parameters
+    ----------
+    c_vars: set
+        Set of all selected model variables.
+    d_deps: dict
+        Dictionary of dependencies needed to run vars and modules.
+    s_deps: set
+        Set of stateful objects to update when integrating selected
+        model variables.
+
+    """
+    c_vars: Set[str]
+    d_deps: Dict[str, set]
+    s_deps: Set[str]
+
+    def __str__(self):
+        text = print_objects_format(self.c_vars, "Selected variables")
+
+        if self.d_deps["initial"]:
+            text += print_objects_format(
+                self.d_deps["initial"],
+                "\nDependencies for initialization only")
+        if self.d_deps["step"]:
+            text += print_objects_format(
+                self.d_deps["step"],
+                "\nDependencies that may change over time")
+        if self.d_deps["lookup"]:
+            text += print_objects_format(
+                self.d_deps["lookup"],
+                "\nLookup table dependencies")
+
+        text += print_objects_format(
+            self.s_deps,
+            "\nStateful objects integrated with the selected variables")
+
+        return text
+
+
 class ProgressBar:
     """
     Progress bar for integration
@@ -539,3 +498,66 @@ class ProgressBar:
         except AttributeError:
             # Error if bar is not imported
             pass
+
+
+class UniqueDims():
+    """
+    Helper class to create unique dimension names for data_vars with the
+    same dimension name but different coords in xarray Datasets.
+    """
+    def __init__(self, original_dim_name):
+        self.dim_name = original_dim_name
+        self.dim_prefix = self.dim_name + "_#"
+        self.unique_dims = []
+        self.num = 1
+
+    def name_new_dim(self, dim_name, coords):
+        """
+        Returns either a new name (original_dim_name + _# + num) if the coords
+        list is not in unique_dims, or the preexisting dimension name if it is.
+        Parameters
+        ----------
+        dim_name: str
+            This argument is used to verify that we are passing the right
+            dimension name to the class.
+        coords: list
+            List of coordinates of a dimension.
+
+        Returns
+        -------
+        Updated name of the original dimension.
+        """
+        if dim_name != self.dim_name:
+            raise ValueError(
+                "This object is configured to process dimension "
+                f"{self.dim_name} and it's being passed a dimension "
+                f"named {dim_name}"
+            )
+        if self.is_new(coords):
+            new_dim_name = self.dim_prefix + str(self.num)
+            self.unique_dims.append((new_dim_name, coords))
+            self.num += 1
+            return new_dim_name
+        else:
+            for y in self.unique_dims:
+                if np.array_equal(coords, y[1]):
+                    return y[0]
+
+    def is_new(self, coords):
+        """
+        Checks if coords is already in the unique_dims list or not.
+
+        Parameters
+        ----------
+        coords: list
+            List of coordinates of a dimension.
+
+        Returns
+        -------
+        bool
+        """
+        if not any(
+             map(lambda y: np.array_equal(y[1], coords),
+                 self.unique_dims)):
+            return True
+        return False
